pub struct InfNanNegOneOrLessError;Expand description
The error that that is returned when trying to convert a f64 value that is less than or equal to -1.0
into a FiniteAboveNegOneF64 with the TryFrom trait.